package VMOMI::HostCapabilityVmDirectPathGen2UnsupportedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
